import ujson
import httplib2
import json
import sys
import types
from jsonshrink import *

TYPE = 'TYPE'
PATH = 'PATH'
VALUE = 'VALUE'

# Borrowed from http://djangosnippets.org/snippets/2247/
# with some modifications.
class Diff(object):
  def __init__(self, first, second, with_values=True):
    self.difference = []
    self.seen = []
    not_with_values = not with_values
    self.str = []
    self.check(first, second, with_values=with_values)

  def check(self, first, second, path='', with_values=True):
    if with_values and second != None:
      if not isinstance(first, type(second)):
        message = '%s - %s, %s' % (path, type(first).__name__, type(second).__name__)
        self.save_diff(message, TYPE)
        return False

    if isinstance(first, dict):
      for key in first:
        if key == 'sym' or key == 'syms':
            continue
        # the first part of path must not have trailing dot.
        if len(path) == 0:
          new_path = key
        else:
          new_path = "%s.%s" % (path, key)

        if isinstance(second, dict):
          if second.has_key(key):
            sec = second[key]
          else:
            #  there are key in the first, that is not presented in the second
            self.save_diff(new_path, PATH)

            # prevent further values checking.
            sec = None

          # recursive call
          if sec != None:
            b = self.check(first[key], sec, path=new_path, with_values=with_values)
            if isinstance(b,dict):
                first[key] = b
            elif b==0:
                first[key] = sec
            else:
                if not isinstance(first[key],list) and not isinstance(first[key],dict):
                    first[key] = None
                elif first[key]==[None] or len(first[key])==0:
                    first[key]=None
        else:#second is not dict
          # second is not dict. every key from first goes to the difference
          self.save_diff(new_path, PATH)
          b = self.check(first[key], second, path=new_path, with_values=with_values)
          if b==0:
              first[key] = second
          elif b==1:
              if not isinstance(first[key],list) and not isinstance(first[key],dict):
                first[key] = None

    # if object is list, loop over it and check.
    elif isinstance(first, list):
      for (index, item) in enumerate(first):
        new_path = "%s[%s]" % (path, index)
        # try to get the same index from second
        sec = None
        if second != None:
          try:
            sec = second[index]
          except (IndexError, KeyError):
            # goes to difference
            self.save_diff('%s - %s' % (new_path, type(item).__name__), TYPE)

        # recursive call
        b = self.check(first[index], sec, path=new_path, with_values=with_values)
        if b==0:
              first[index] = sec
        elif b==1:
              if not isinstance(first[index],list) and not isinstance(first[index],dict):
                first[index] = None
          #return b
    # not list, not dict. check for equality (only if with_values is True) and return.
    else:
      if with_values and second != None:
        if first != second:
          self.save_diff('%s - %s | %s' % (path, first, second), VALUE)
          return 0
        else:
          return 1
      #return True

  def save_diff(self, diff_message, type_):
    if diff_message not in self.difference:
      self.seen.append(diff_message)
      self.difference.append((type_, diff_message))

def diff(json1, json2):
  Diff(json1, json2)
  return shrink(json1)

if __name__ =='__main__':
  s0='''{"dt":"2015-06-26 10:40:57","data":[{"_tinfo":{"syms":"NQ","uPNL":-49.5,"aPNL":-40.5,"statuz":2,"ps":[5.16],"vo":[-900],"inve":4648.5,"lcc":4000,"cR":-648.5}},{"_tinfo":{"syms":"CYOU","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"EJ","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"RENN","uPNL":58,"aPNL":59,"statuz":2,"ps":[3.90],"vo":[-1000],"inve":3903,"lcc":4000,"cR":97}},{"_tinfo":{"syms":"HTHT","uPNL":1,"aPNL":-0.5,"statuz":1,"ps":[25.82],"vo":[100],"inve":2582,"lcc":4000,"cR":1418}},{"_tinfo":{"syms":"JMEI","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"BITA","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"CEA","uPNL":-175.80,"aPNL":-175.55,"statuz":2,"ps":[42.00],"vo":[-50],"inve":2100.44,"lcc":4000,"cR":1899.55}},{"_tinfo":{"syms":"FXI","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"MOBL","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"SPY","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"LEJU","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"SINA","uPNL":0,"aPNL":0,"statuz":7,"ps":[59.37],"vo":[-50],"inve":2968.94,"lcc":4000,"cR":1031.05}},{"_tinfo":{"syms":"SOHU","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"CTRP","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"NTES","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"QIHU","uPNL":0,"aPNL":48.70,"statuz":7,"ps":[70.90],"vo":[-50],"inve":3545.45,"lcc":4000,"cR":454.54}},{"_tinfo":{"syms":"QUNR","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"CMCM","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"SFUN","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"FENG","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"DANG","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"JOBS","uPNL":1.89,"aPNL":0,"statuz":2,"ps":[34.10],"vo":[-100],"inve":3410.90,"lcc":4000,"cR":589.09}},{"_tinfo":{"syms":"PWRD","uPNL":-137.20,"aPNL":0,"statuz":2,"ps":[19.07],"vo":[-200],"inve":3815,"lcc":4000,"cR":185}},{"_tinfo":{"syms":"DATE","uPNL":38.5,"aPNL":0,"statuz":2,"ps":[7.56],"vo":[-500],"inve":3781,"lcc":4000,"cR":219}},{"_tinfo":{"syms":"CCIH","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"BIDU","uPNL":0,"aPNL":0,"statuz":7,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"GOMO","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"JRJC","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"ATHM","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"HMIN","uPNL":-42.5,"aPNL":0,"statuz":2,"ps":[30.89],"vo":[-100],"inve":3089,"lcc":4000,"cR":911}},{"_tinfo":{"syms":"TAOM","uPNL":94.5,"aPNL":0,"statuz":1,"ps":[3.12],"vo":[300],"inve":937.5,"lcc":4000,"cR":3062.5}},{"_tinfo":{"syms":"WUBA","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"WB","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"YY","uPNL":210.04,"aPNL":210.04,"statuz":4,"ps":[69.26],"vo":[50],"inve":3463.5,"lcc":4000,"cR":536.5}},{"_tinfo":{"syms":"ZNH","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_mkdata":{"sym":"NQ","bid":5.19,"ask":5.21,"bs":1,"as":11,"H":5.23,"L":5.15,"C":5.15,"O":5.17,"LP":5.21,"WH13":6.54,"WL13":3.35,"WH26":6.54,"WL26":3.22,"WH52":10.69,"WL52":3.22,"vrate":2625,"trate":1,"LRTH":5.16,"OCVol":460,"OPVol":200,"PCVOR":0.43,"OCOI":189388,"OPOI":57662,"PCOIR":0.30,"pos":-900,"avgP":5.16}},{"_mkdata":{"sym":"CYOU","bid":30.69,"ask":30.96,"bs":1,"as":1,"H":31.28,"L":30.71,"C":31.05,"O":30.14,"LP":0,"WH13":35.27,"WL13":25.51,"WH26":35.27,"WL26":24.07,"WH52":35.27,"WL52":17.12,"vrate":141,"trate":0,"LRTH":31.05,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":6578,"OPOI":1918,"PCOIR":0.29,"pos":0,"avgP":0}},{"_mkdata":{"sym":"EJ","bid":6.90,"ask":6.91,"bs":19,"as":12,"H":6.92,"L":6.86,"C":6.94,"O":6.91,"LP":6.91,"WH13":7.17,"WL13":5,"WH26":8.48,"WL26":4.79,"WH52":11.39,"WL52":4.79,"vrate":3400,"trate":26,"LRTH":6.95,"OCVol":10,"OPVol":0,"PCVOR":-1,"OCOI":24108,"OPOI":10834,"PCOIR":0.44,"pos":0,"avgP":0}},{"_mkdata":{"sym":"RENN","bid":3.81,"ask":3.85,"bs":2,"as":5,"H":3.85,"L":3.83,"C":3.85,"O":3.89,"LP":3.84,"WH13":4.45,"WL13":2.37,"WH26":4.45,"WL26":2.35,"WH52":4.45,"WL52":2.35,"vrate":200,"trate":1,"LRTH":3.85,"OCVol":9,"OPVol":0,"PCVOR":-1,"OCOI":31926,"OPOI":13333,"PCOIR":0.41,"pos":-1000,"avgP":3.90}},{"_mkdata":{"sym":"HTHT","bid":25.64,"ask":25.84,"bs":1,"as":1,"H":25.82,"L":25.60,"C":25.77,"O":25.82,"LP":25.82,"WH13":30.98,"WL13":19.07,"WH26":30.98,"WL26":15.35,"WH52":30.98,"WL52":15.35,"vrate":0,"trate":0,"LRTH":25.77,"OCVol":0,"OPVol":50,"PCVOR":-1,"OCOI":108,"OPOI":94,"PCOIR":0.87,"pos":100,"avgP":25.82}},{"_mkdata":{"sym":"JMEI","bid":23.27,"ask":23.37,"bs":2,"as":2,"H":23.5,"L":22.91,"C":23.98,"O":23.5,"LP":23.30,"WH13":28.17,"WL13":15.11,"WH26":28.17,"WL26":12.13,"WH52":39.42,"WL52":12.13,"vrate":23475,"trate":24,"LRTH":23.96,"OCVol":103,"OPVol":0,"PCVOR":-1,"OCOI":53175,"OPOI":21899,"PCOIR":0.41,"pos":0,"avgP":0}},{"_mkdata":{"sym":"BITA","bid":54.99,"ask":55.18,"bs":1,"as":2,"H":55.28,"L":54.82,"C":55.14,"O":55.11,"LP":54.96,"WH13":67.62,"WL13":48.88,"WH26":95,"WL26":45.28,"WH52":98.28,"WL52":43.78,"vrate":1200,"trate":0,"LRTH":55.20,"OCVol":29,"OPVol":0,"PCVOR":-1,"OCOI":28964,"OPOI":18156,"PCOIR":0.62,"pos":0,"avgP":0}},{"_mkdata":{"sym":"CEA","bid":45.35,"ask":45.60,"bs":1,"as":1,"H":45.72,"L":45.57,"C":45.96,"O":44.64,"LP":45.52,"WH13":47.50,"WL13":26.69,"WH26":47.50,"WL26":22.12,"WH52":47.50,"WL52":15.22,"vrate":0,"trate":0,"LRTH":45.93,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":0,"OPOI":0,"PCOIR":-1,"pos":-50,"avgP":42.00}},{"_mkdata":{"sym":"FXI","bid":47.68,"ask":47.70,"bs":60,"as":45,"H":47.93,"L":47.67,"C":48.35,"O":47.88,"LP":47.70,"WH13":52.60,"WL13":42.07,"WH26":52.60,"WL26":40.39,"WH52":52.60,"WL52":35.96,"vrate":83900,"trate":223,"LRTH":48.35,"OCVol":1399,"OPVol":754,"PCVOR":0.53,"OCOI":1749723,"OPOI":1673412,"PCOIR":0.95,"pos":0,"avgP":0}},{"_mkdata":{"sym":"MOBL","bid":6.21,"ask":6.25,"bs":1,"as":1,"H":6.44,"L":6.25,"C":6.26,"O":6.33,"LP":6.25,"WH13":9.67,"WL13":5.87,"WH26":10.15,"WL26":5.87,"WH52":12.96,"WL52":5.87,"vrate":1060,"trate":3,"LRTH":6.26,"OCVol":5,"OPVol":0,"PCVOR":-1,"OCOI":4358,"OPOI":1038,"PCOIR":0.23,"pos":0,"avgP":0}},{"_mkdata":{"sym":"SPY","bid":210.68,"ask":210.69,"bs":20,"as":52,"H":211.21,"L":210.59,"C":210.5,"O":211.09,"LP":210.68,"WH13":212.74,"WL13":203.09,"WH26":212.74,"WL26":195.90,"WH52":212.74,"WL52":178.81,"vrate":683800,"trate":2342,"LRTH":210.49,"OCVol":27669,"OPVol":50751,"PCVOR":1.83,"OCOI":5792499,"OPOI":12152942,"PCOIR":2.09,"pos":0,"avgP":0}},{"_mkdata":{"sym":"LEJU","bid":8.66,"ask":8.81,"bs":1,"as":1,"H":8.86,"L":8.73,"C":8.82,"O":8.83,"LP":8.82,"WH13":10.82,"WL13":7.12,"WH26":13.30,"WL26":6.46,"WH52":18.60,"WL52":6.46,"vrate":300,"trate":0,"LRTH":8.83,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":4276,"OPOI":1679,"PCOIR":0.39,"pos":0,"avgP":0}},{"_mkdata":{"sym":"SINA","bid":56.61,"ask":56.71,"bs":3,"as":2,"H":57.00,"L":56.5,"C":57.00,"O":56.88,"LP":56.68,"WH13":61.25,"WL13":31.92,"WH26":61.25,"WL26":31.92,"WH52":61.25,"WL52":31.92,"vrate":3535,"trate":25,"LRTH":57.02,"OCVol":69,"OPVol":41,"PCVOR":0.59,"OCOI":74388,"OPOI":167419,"PCOIR":2.25,"pos":-50,"avgP":59.37}},{"_mkdata":{"sym":"SOHU","bid":64.40,"ask":65.15,"bs":1,"as":1,"H":64.81,"L":64.45,"C":64.90,"O":64.54,"LP":64.54,"WH13":71.78,"WL13":52.53,"WH26":71.78,"WL26":48.82,"WH52":71.78,"WL52":42.03,"vrate":1272,"trate":0,"LRTH":64.90,"OCVol":16,"OPVol":0,"PCVOR":-1,"OCOI":15866,"OPOI":8680,"PCOIR":0.54,"pos":0,"avgP":0}},{"_mkdata":{"sym":"CTRP","bid":72.93,"ask":73,"bs":3,"as":2,"H":73.48,"L":72.87,"C":72.92,"O":73.06,"LP":72.95,"WH13":87.62,"WL13":57.59,"WH26":87.62,"WL26":43.07,"WH52":87.62,"WL52":40.74,"vrate":32400,"trate":251,"LRTH":72.90,"OCVol":83,"OPVol":30,"PCVOR":0.36,"OCOI":64056,"OPOI":66877,"PCOIR":1.04,"pos":0,"avgP":0}},{"_mkdata":{"sym":"NTES","bid":147.36,"ask":148.44,"bs":2,"as":2,"H":149.49,"L":147.56,"C":148.18,"O":148.97,"LP":148.40,"WH13":154.88,"WL13":98.37,"WH26":154.88,"WL26":93.78,"WH52":154.88,"WL52":72.07,"vrate":1131,"trate":2,"LRTH":148.24,"OCVol":1,"OPVol":1,"PCVOR":-1,"OCOI":23186,"OPOI":15066,"PCOIR":0.64,"pos":0,"avgP":0}},{"_mkdata":{"sym":"QIHU","bid":69.51,"ask":69.56,"bs":1,"as":3,"H":69.98,"L":69.45,"C":69.85,"O":69.89,"LP":69.51,"WH13":72.5,"WL13":49.63,"WH26":72.5,"WL26":44.56,"WH52":104.62,"WL52":44.56,"vrate":15600,"trate":81,"LRTH":69.87,"OCVol":414,"OPVol":49,"PCVOR":0.11,"OCOI":106335,"OPOI":120337,"PCOIR":1.13,"pos":-50,"avgP":70.90}},{"_mkdata":{"sym":"QUNR","bid":42.43,"ask":42.60,"bs":1,"as":1,"H":42.97,"L":42.50,"C":42.64,"O":42.96,"LP":42.59,"WH13":54.22,"WL13":37.86,"WH26":54.22,"WL26":26.39,"WH52":54.22,"WL52":23.55,"vrate":1838,"trate":0,"LRTH":42.64,"OCVol":0,"OPVol":6,"PCVOR":-1,"OCOI":57568,"OPOI":13735,"PCOIR":0.23,"pos":0,"avgP":0}},{"_mkdata":{"sym":"CMCM","bid":33.31,"ask":33.49,"bs":1,"as":3,"H":33.46,"L":33,"C":33.07,"O":33.27,"LP":33.40,"WH13":36.61,"WL13":16.48,"WH26":36.61,"WL26":14.92,"WH52":36.61,"WL52":14.77,"vrate":26400,"trate":69,"LRTH":33.03,"OCVol":3,"OPVol":6,"PCVOR":2,"OCOI":10548,"OPOI":9457,"PCOIR":0.89,"pos":0,"avgP":0}},{"_mkdata":{"sym":"SFUN","bid":9,"ask":9.00,"bs":32,"as":53,"H":9.01,"L":8.67,"C":8.83,"O":8.77,"LP":9.00,"WH13":10.01,"WL13":5.82,"WH26":10.01,"WL26":5.25,"WH52":12.43,"WL52":5.25,"vrate":37335,"trate":79,"LRTH":8.84,"OCVol":35,"OPVol":0,"PCVOR":-1,"OCOI":140347,"OPOI":165005,"PCOIR":1.17,"pos":0,"avgP":0}},{"_mkdata":{"sym":"FENG","bid":8.66,"ask":8.69,"bs":1,"as":1,"H":8.74,"L":8.66,"C":8.78,"O":8.68,"LP":8.69,"WH13":9.89,"WL13":5.61,"WH26":9.89,"WL26":5.61,"WH52":11.31,"WL52":5.61,"vrate":1200,"trate":2,"LRTH":8.80,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":3107,"OPOI":2028,"PCOIR":0.65,"pos":0,"avgP":0}},{"_mkdata":{"sym":"DANG","bid":10.35,"ask":10.39,"bs":54,"as":6,"H":10.47,"L":10.30,"C":10.42,"O":10.35,"LP":10.39,"WH13":11.5,"WL13":7.86,"WH26":11.5,"WL26":7.5,"WH52":16.39,"WL52":7.5,"vrate":11900,"trate":14,"LRTH":10.42,"OCVol":72,"OPVol":0,"PCVOR":-1,"OCOI":35960,"OPOI":17530,"PCOIR":0.48,"pos":0,"avgP":0}},{"_mkdata":{"sym":"JOBS","bid":33.79,"ask":34.14,"bs":3,"as":1,"H":34.17,"L":34.17,"C":34.15,"O":22.03,"LP":34.09,"WH13":37.77,"WL13":29.80,"WH26":38.11,"WL26":29.80,"WH52":38.57,"WL52":29.23,"vrate":0,"trate":0,"LRTH":34.17,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":708,"OPOI":483,"PCOIR":0.68,"pos":-100,"avgP":34.10}},{"_mkdata":{"sym":"PWRD","bid":19.75,"ask":19.76,"bs":1,"as":3,"H":19.76,"L":19.71,"C":19.71,"O":19.73,"LP":19.74,"WH13":19.92,"WL13":17.80,"WH26":19.92,"WL26":15.65,"WH52":23.48,"WL52":14.77,"vrate":6081,"trate":0,"LRTH":19.71,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":8270,"OPOI":6455,"PCOIR":0.78,"pos":-200,"avgP":19.07}},{"_mkdata":{"sym":"DATE","bid":7.34,"ask":7.49,"bs":1,"as":5,"H":7.59,"L":7.37,"C":7.41,"O":7.58,"LP":7.48,"WH13":9.48,"WL13":5.04,"WH26":9.48,"WL26":4.17,"WH52":9.48,"WL52":4.17,"vrate":424,"trate":2,"LRTH":7.41,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":5908,"OPOI":1326,"PCOIR":0.22,"pos":-500,"avgP":7.56}},{"_mkdata":{"sym":"CCIH","bid":13.24,"ask":13.39,"bs":15,"as":1,"H":13.32,"L":13.15,"C":13.35,"O":13.22,"LP":13.27,"WH13":15.69,"WL13":8.26,"WH26":15.69,"WL26":7.91,"WH52":17.17,"WL52":7.91,"vrate":2828,"trate":0,"LRTH":13.35,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":3147,"OPOI":423,"PCOIR":0.13,"pos":0,"avgP":0}},{"_mkdata":{"sym":"BIDU","bid":209.25,"ask":209.52,"bs":3,"as":3,"H":211,"L":209.19,"C":210.31,"O":211,"LP":209.37,"WH13":223.94,"WL13":188.59,"WH26":237.43,"WL26":188.59,"WH52":251.99,"WL52":176.69,"vrate":15000,"trate":138,"LRTH":210.38,"OCVol":402,"OPVol":291,"PCVOR":0.72,"OCOI":145175,"OPOI":110343,"PCOIR":0.76,"pos":0,"avgP":0}},{"_mkdata":{"sym":"GOMO","bid":4.67,"ask":4.82,"bs":1,"as":1,"H":4.76,"L":4.76,"C":4.76,"O":5.08,"LP":0,"WH13":5.23,"WL13":3.35,"WH26":5.59,"WL26":3.25,"WH52":14.4,"WL52":3.25,"vrate":0,"trate":0,"LRTH":4.74,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":563,"OPOI":1417,"PCOIR":2.51,"pos":0,"avgP":0}},{"_mkdata":{"sym":"JRJC","bid":5.80,"ask":5.84,"bs":4,"as":2,"H":5.87,"L":5.76,"C":5.90,"O":5.80,"LP":5.84,"WH13":6.40,"WL13":3.89,"WH26":6.75,"WL26":3.89,"WH52":11.88,"WL52":3.50,"vrate":1944,"trate":0,"LRTH":5.87,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":4751,"OPOI":2916,"PCOIR":0.61,"pos":0,"avgP":0}},{"_mkdata":{"sym":"ATHM","bid":50.10,"ask":50.39,"bs":1,"as":1,"H":51.45,"L":49.89,"C":51.53,"O":51.06,"LP":50.20,"WH13":56.57,"WL13":42.75,"WH26":56.57,"WL26":34.5,"WH52":57.88,"WL52":31.85,"vrate":8202,"trate":22,"LRTH":51.50,"OCVol":828,"OPVol":12,"PCVOR":0.01,"OCOI":5876,"OPOI":3176,"PCOIR":0.54,"pos":0,"avgP":0}},{"_mkdata":{"sym":"HMIN","bid":0,"ask":0,"bs":0,"as":0,"H":0,"L":0,"C":0,"O":0,"LP":31.31,"WH13":0,"WL13":0,"WH26":0,"WL26":0,"WH52":0,"WL52":0,"vrate":0,"trate":0,"LRTH":0,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":0,"OPOI":0,"PCOIR":-1,"pos":-100,"avgP":30.89}},{"_mkdata":{"sym":"TAOM","bid":0,"ask":0,"bs":0,"as":0,"H":0,"L":0,"C":0,"O":0,"LP":3.43,"WH13":0,"WL13":0,"WH26":0,"WL26":0,"WH52":0,"WL52":0,"vrate":0,"trate":0,"LRTH":0,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":0,"OPOI":0,"PCOIR":-1,"pos":300,"avgP":3.12}},{"_mkdata":{"sym":"WUBA","bid":67.70,"ask":68.09,"bs":1,"as":1,"H":69.10,"L":67.70,"C":69.12,"O":69.06,"LP":67.87,"WH13":83.70,"WL13":47.24,"WH26":83.70,"WL26":37.17,"WH52":83.70,"WL52":34.64,"vrate":10800,"trate":66,"LRTH":69.04,"OCVol":28,"OPVol":0,"PCVOR":-1,"OCOI":11095,"OPOI":18530,"PCOIR":1.67,"pos":0,"avgP":0}},{"_mkdata":{"sym":"WB","bid":18.64,"ask":18.69,"bs":6,"as":8,"H":19,"L":18.62,"C":19.03,"O":18.87,"LP":18.64,"WH13":20.69,"WL13":12.65,"WH26":20.69,"WL26":12.10,"WH52":26.07,"WL52":12.10,"vrate":3300,"trate":3,"LRTH":19.03,"OCVol":40,"OPVol":50,"PCVOR":1.25,"OCOI":22509,"OPOI":6106,"PCOIR":0.27,"pos":0,"avgP":0}},{"_mkdata":{"sym":"YY","bid":74,"ask":74.5,"bs":1,"as":5,"H":75.53,"L":71.59,"C":75.5,"O":75.53,"LP":74.23,"WH13":81.70,"WL13":52.84,"WH26":81.70,"WL26":50.52,"WH52":96.39,"WL52":50.52,"vrate":1150,"trate":0,"LRTH":75.51,"OCVol":95,"OPVol":57,"PCVOR":0.59,"OCOI":31251,"OPOI":44298,"PCOIR":1.41,"pos":50,"avgP":69.26}},{"_mkdata":{"sym":"ZNH","bid":-1,"ask":-1,"bs":0,"as":0,"H":0,"L":0,"C":63.28,"O":0,"LP":0,"WH13":64.42,"WL13":30.16,"WH26":64.42,"WL26":22.48,"WH52":64.42,"WL52":14.9,"vrate":0,"trate":0,"LRTH":63.35,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":1187,"OPOI":984,"PCOIR":0.82,"pos":0,"avgP":0}},{"_portfolio":{"uPNL":-1.05,"aPNL":101.19,"lcc":144000,"inve":38245.24,"cR":105754.74,"nlc":2658408.39}}]}'''
  s1='''{"dt":"2015-06-26 10:40:57","data":[{"_tinfo":{"syms":"NQ","uPNL":-49.5,"aPNL":-40.5,"statuz":2,"ps":[5.16],"vo":[-900],"inve":4648.5,"lcc":4000,"cR":-648.5}},{"_tinfo":{"syms":"CYOU","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"EJ","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"RENN","uPNL":58,"aPNL":59,"statuz":2,"ps":[3.90],"vo":[-1000],"inve":3903,"lcc":4000,"cR":97}},{"_tinfo":{"syms":"HTHT","uPNL":1,"aPNL":-0.5,"statuz":1,"ps":[25.82],"vo":[100],"inve":2582,"lcc":4000,"cR":1418}},{"_tinfo":{"syms":"JMEI","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"BITA","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"CEA","uPNL":-175.80,"aPNL":-175.55,"statuz":2,"ps":[42.00],"vo":[-50],"inve":2100.44,"lcc":4000,"cR":1899.55}},{"_tinfo":{"syms":"FXI","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"MOBL","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"SPY","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"LEJU","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"SINA","uPNL":0,"aPNL":0,"statuz":7,"ps":[59.37],"vo":[-50],"inve":2968.94,"lcc":4000,"cR":1031.05}},{"_tinfo":{"syms":"SOHU","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"CTRP","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"NTES","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"QIHU","uPNL":0,"aPNL":48.70,"statuz":7,"ps":[70.90],"vo":[-50],"inve":3545.45,"lcc":4000,"cR":454.54}},{"_tinfo":{"syms":"QUNR","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"CMCM","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"SFUN","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"FENG","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"DANG","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"JOBS","uPNL":1.89,"aPNL":0,"statuz":2,"ps":[34.10],"vo":[-100],"inve":3410.90,"lcc":4000,"cR":589.09}},{"_tinfo":{"syms":"PWRD","uPNL":-137.20,"aPNL":0,"statuz":2,"ps":[19.07],"vo":[-200],"inve":3815,"lcc":4000,"cR":185}},{"_tinfo":{"syms":"DATE","uPNL":38.5,"aPNL":0,"statuz":2,"ps":[7.56],"vo":[-500],"inve":3781,"lcc":4000,"cR":219}},{"_tinfo":{"syms":"CCIH","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"BIDU","uPNL":0,"aPNL":0,"statuz":7,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"GOMO","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"JRJC","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"ATHM","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"HMIN","uPNL":-42.5,"aPNL":0,"statuz":2,"ps":[30.89],"vo":[-100],"inve":3089,"lcc":4000,"cR":911}},{"_tinfo":{"syms":"TAOM","uPNL":94.5,"aPNL":0,"statuz":1,"ps":[3.12],"vo":[300],"inve":937.5,"lcc":4000,"cR":3062.5}},{"_tinfo":{"syms":"WUBA","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"WB","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_tinfo":{"syms":"YY","uPNL":210.04,"aPNL":210.04,"statuz":4,"ps":[69.26],"vo":[50],"inve":3463.5,"lcc":4000,"cR":536.5}},{"_tinfo":{"syms":"ZNH","uPNL":0,"aPNL":0,"statuz":0,"ps":[],"vo":[],"inve":0,"lcc":4000,"cR":4000}},{"_mkdata":{"sym":"NQ","bid":5.19,"ask":5.21,"bs":1,"as":11,"H":5.23,"L":5.15,"C":5.15,"O":5.17,"LP":5.21,"WH13":6.54,"WL13":3.35,"WH26":6.54,"WL26":3.22,"WH52":10.69,"WL52":3.22,"vrate":2625,"trate":1,"LRTH":5.16,"OCVol":460,"OPVol":200,"PCVOR":0.43,"OCOI":189388,"OPOI":57662,"PCOIR":0.30,"pos":-900,"avgP":5.16}},{"_mkdata":{"sym":"CYOU","bid":30.69,"ask":30.96,"bs":1,"as":1,"H":31.28,"L":30.71,"C":31.05,"O":30.14,"LP":0,"WH13":35.27,"WL13":25.51,"WH26":35.27,"WL26":24.07,"WH52":35.27,"WL52":17.12,"vrate":141,"trate":0,"LRTH":31.05,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":6578,"OPOI":1918,"PCOIR":0.29,"pos":0,"avgP":0}},{"_mkdata":{"sym":"EJ","bid":6.90,"ask":6.91,"bs":19,"as":12,"H":6.92,"L":6.86,"C":6.94,"O":6.91,"LP":6.91,"WH13":7.17,"WL13":5,"WH26":8.48,"WL26":4.79,"WH52":11.39,"WL52":4.79,"vrate":3400,"trate":26,"LRTH":6.95,"OCVol":10,"OPVol":0,"PCVOR":-1,"OCOI":24108,"OPOI":10834,"PCOIR":0.44,"pos":0,"avgP":0}},{"_mkdata":{"sym":"RENN","bid":3.81,"ask":3.85,"bs":2,"as":5,"H":3.85,"L":3.83,"C":3.85,"O":3.89,"LP":3.84,"WH13":4.45,"WL13":2.37,"WH26":4.45,"WL26":2.35,"WH52":4.45,"WL52":2.35,"vrate":200,"trate":1,"LRTH":3.85,"OCVol":9,"OPVol":0,"PCVOR":-1,"OCOI":31926,"OPOI":13333,"PCOIR":0.41,"pos":-1000,"avgP":3.90}},{"_mkdata":{"sym":"HTHT","bid":25.64,"ask":25.84,"bs":1,"as":1,"H":25.82,"L":25.60,"C":25.77,"O":25.82,"LP":25.82,"WH13":30.98,"WL13":19.07,"WH26":30.98,"WL26":15.35,"WH52":30.98,"WL52":15.35,"vrate":0,"trate":0,"LRTH":25.77,"OCVol":0,"OPVol":50,"PCVOR":-1,"OCOI":108,"OPOI":94,"PCOIR":0.87,"pos":100,"avgP":25.82}},{"_mkdata":{"sym":"JMEI","bid":23.27,"ask":23.37,"bs":2,"as":2,"H":23.5,"L":22.91,"C":23.98,"O":23.5,"LP":23.30,"WH13":28.17,"WL13":15.11,"WH26":28.17,"WL26":12.13,"WH52":39.42,"WL52":12.13,"vrate":23475,"trate":24,"LRTH":23.96,"OCVol":103,"OPVol":0,"PCVOR":-1,"OCOI":53175,"OPOI":21899,"PCOIR":0.41,"pos":0,"avgP":0}},{"_mkdata":{"sym":"BITA","bid":54.99,"ask":55.18,"bs":1,"as":2,"H":55.28,"L":54.82,"C":55.14,"O":55.11,"LP":54.96,"WH13":67.62,"WL13":48.88,"WH26":95,"WL26":45.28,"WH52":98.28,"WL52":43.78,"vrate":1200,"trate":0,"LRTH":55.20,"OCVol":29,"OPVol":0,"PCVOR":-1,"OCOI":28964,"OPOI":18156,"PCOIR":0.62,"pos":0,"avgP":0}},{"_mkdata":{"sym":"CEA","bid":45.35,"ask":45.60,"bs":1,"as":1,"H":45.72,"L":45.57,"C":45.96,"O":44.64,"LP":45.52,"WH13":47.50,"WL13":26.69,"WH26":47.50,"WL26":22.12,"WH52":47.50,"WL52":15.22,"vrate":0,"trate":0,"LRTH":45.93,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":0,"OPOI":0,"PCOIR":-1,"pos":-50,"avgP":42.00}},{"_mkdata":{"sym":"FXI","bid":47.68,"ask":47.70,"bs":60,"as":45,"H":47.93,"L":47.67,"C":48.35,"O":47.88,"LP":47.70,"WH13":52.60,"WL13":42.07,"WH26":52.60,"WL26":40.39,"WH52":52.60,"WL52":35.96,"vrate":83900,"trate":223,"LRTH":48.35,"OCVol":1399,"OPVol":754,"PCVOR":0.53,"OCOI":1749723,"OPOI":1673412,"PCOIR":0.95,"pos":0,"avgP":0}},{"_mkdata":{"sym":"MOBL","bid":6.21,"ask":6.25,"bs":1,"as":1,"H":6.44,"L":6.25,"C":6.26,"O":6.33,"LP":6.25,"WH13":9.67,"WL13":5.87,"WH26":10.15,"WL26":5.87,"WH52":12.96,"WL52":5.87,"vrate":1060,"trate":3,"LRTH":6.26,"OCVol":5,"OPVol":0,"PCVOR":-1,"OCOI":4358,"OPOI":1038,"PCOIR":0.23,"pos":0,"avgP":0}},{"_mkdata":{"sym":"SPY","bid":210.68,"ask":210.69,"bs":20,"as":52,"H":211.21,"L":210.59,"C":210.5,"O":211.09,"LP":210.68,"WH13":212.74,"WL13":203.09,"WH26":212.74,"WL26":195.90,"WH52":212.74,"WL52":178.81,"vrate":683800,"trate":2342,"LRTH":210.49,"OCVol":27669,"OPVol":50751,"PCVOR":1.83,"OCOI":5792499,"OPOI":12152942,"PCOIR":2.09,"pos":0,"avgP":0}},{"_mkdata":{"sym":"LEJU","bid":8.66,"ask":8.81,"bs":1,"as":1,"H":8.86,"L":8.73,"C":8.82,"O":8.83,"LP":8.82,"WH13":10.82,"WL13":7.12,"WH26":13.30,"WL26":6.46,"WH52":18.60,"WL52":6.46,"vrate":300,"trate":0,"LRTH":8.83,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":4276,"OPOI":1679,"PCOIR":0.39,"pos":0,"avgP":0}},{"_mkdata":{"sym":"SINA","bid":56.61,"ask":56.71,"bs":3,"as":2,"H":57.00,"L":56.5,"C":57.00,"O":56.88,"LP":56.68,"WH13":61.25,"WL13":31.92,"WH26":61.25,"WL26":31.92,"WH52":61.25,"WL52":31.92,"vrate":3535,"trate":25,"LRTH":57.02,"OCVol":69,"OPVol":41,"PCVOR":0.59,"OCOI":74388,"OPOI":167419,"PCOIR":2.25,"pos":-50,"avgP":59.37}},{"_mkdata":{"sym":"SOHU","bid":64.40,"ask":65.15,"bs":1,"as":1,"H":64.81,"L":64.45,"C":64.90,"O":64.54,"LP":64.54,"WH13":71.78,"WL13":52.53,"WH26":71.78,"WL26":48.82,"WH52":71.78,"WL52":42.03,"vrate":1272,"trate":0,"LRTH":64.90,"OCVol":16,"OPVol":0,"PCVOR":-1,"OCOI":15866,"OPOI":8680,"PCOIR":0.54,"pos":0,"avgP":0}},{"_mkdata":{"sym":"CTRP","bid":72.93,"ask":73,"bs":3,"as":2,"H":73.48,"L":72.87,"C":72.92,"O":73.06,"LP":72.95,"WH13":87.62,"WL13":57.59,"WH26":87.62,"WL26":43.07,"WH52":87.62,"WL52":40.74,"vrate":32400,"trate":251,"LRTH":72.90,"OCVol":83,"OPVol":30,"PCVOR":0.36,"OCOI":64056,"OPOI":66877,"PCOIR":1.04,"pos":0,"avgP":0}},{"_mkdata":{"sym":"NTES","bid":147.36,"ask":148.44,"bs":2,"as":2,"H":149.49,"L":147.56,"C":148.18,"O":148.97,"LP":148.40,"WH13":154.88,"WL13":98.37,"WH26":154.88,"WL26":93.78,"WH52":154.88,"WL52":72.07,"vrate":1131,"trate":2,"LRTH":148.24,"OCVol":1,"OPVol":1,"PCVOR":-1,"OCOI":23186,"OPOI":15066,"PCOIR":0.64,"pos":0,"avgP":0}},{"_mkdata":{"sym":"QIHU","bid":69.51,"ask":69.56,"bs":1,"as":3,"H":69.98,"L":69.45,"C":69.85,"O":69.89,"LP":69.51,"WH13":72.5,"WL13":49.63,"WH26":72.5,"WL26":44.56,"WH52":104.62,"WL52":44.56,"vrate":15600,"trate":81,"LRTH":69.87,"OCVol":414,"OPVol":49,"PCVOR":0.11,"OCOI":106335,"OPOI":120337,"PCOIR":1.13,"pos":-50,"avgP":70.90}},{"_mkdata":{"sym":"QUNR","bid":42.43,"ask":42.60,"bs":1,"as":1,"H":42.97,"L":42.50,"C":42.64,"O":42.96,"LP":42.59,"WH13":54.22,"WL13":37.86,"WH26":54.22,"WL26":26.39,"WH52":54.22,"WL52":23.55,"vrate":1838,"trate":0,"LRTH":42.64,"OCVol":0,"OPVol":6,"PCVOR":-1,"OCOI":57568,"OPOI":13735,"PCOIR":0.23,"pos":0,"avgP":0}},{"_mkdata":{"sym":"CMCM","bid":33.31,"ask":33.49,"bs":1,"as":3,"H":33.46,"L":33,"C":33.07,"O":33.27,"LP":33.40,"WH13":36.61,"WL13":16.48,"WH26":36.61,"WL26":14.92,"WH52":36.61,"WL52":14.77,"vrate":26400,"trate":69,"LRTH":33.03,"OCVol":3,"OPVol":6,"PCVOR":2,"OCOI":10548,"OPOI":9457,"PCOIR":0.89,"pos":0,"avgP":0}},{"_mkdata":{"sym":"SFUN","bid":9,"ask":9.00,"bs":32,"as":53,"H":9.01,"L":8.67,"C":8.83,"O":8.77,"LP":9.00,"WH13":10.01,"WL13":5.82,"WH26":10.01,"WL26":5.25,"WH52":12.43,"WL52":5.25,"vrate":37335,"trate":79,"LRTH":8.84,"OCVol":35,"OPVol":0,"PCVOR":-1,"OCOI":140347,"OPOI":165005,"PCOIR":1.17,"pos":0,"avgP":0}},{"_mkdata":{"sym":"FENG","bid":8.66,"ask":8.69,"bs":1,"as":1,"H":8.74,"L":8.66,"C":8.78,"O":8.68,"LP":8.69,"WH13":9.89,"WL13":5.61,"WH26":9.89,"WL26":5.61,"WH52":11.31,"WL52":5.61,"vrate":1200,"trate":2,"LRTH":8.80,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":3107,"OPOI":2028,"PCOIR":0.65,"pos":0,"avgP":0}},{"_mkdata":{"sym":"DANG","bid":10.35,"ask":10.39,"bs":54,"as":6,"H":10.47,"L":10.30,"C":10.42,"O":10.35,"LP":10.39,"WH13":11.5,"WL13":7.86,"WH26":11.5,"WL26":7.5,"WH52":16.39,"WL52":7.5,"vrate":11900,"trate":14,"LRTH":10.42,"OCVol":72,"OPVol":0,"PCVOR":-1,"OCOI":35960,"OPOI":17530,"PCOIR":0.48,"pos":0,"avgP":0}},{"_mkdata":{"sym":"JOBS","bid":33.79,"ask":34.14,"bs":3,"as":1,"H":34.17,"L":34.17,"C":34.15,"O":22.03,"LP":34.09,"WH13":37.77,"WL13":29.80,"WH26":38.11,"WL26":29.80,"WH52":38.57,"WL52":29.23,"vrate":0,"trate":0,"LRTH":34.17,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":708,"OPOI":483,"PCOIR":0.68,"pos":-100,"avgP":34.10}},{"_mkdata":{"sym":"PWRD","bid":19.75,"ask":19.76,"bs":1,"as":3,"H":19.76,"L":19.71,"C":19.71,"O":19.73,"LP":19.74,"WH13":19.92,"WL13":17.80,"WH26":19.92,"WL26":15.65,"WH52":23.48,"WL52":14.77,"vrate":6081,"trate":0,"LRTH":19.71,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":8270,"OPOI":6455,"PCOIR":0.78,"pos":-200,"avgP":19.07}},{"_mkdata":{"sym":"DATE","bid":7.34,"ask":7.49,"bs":1,"as":5,"H":7.59,"L":7.37,"C":7.41,"O":7.58,"LP":7.48,"WH13":9.48,"WL13":5.04,"WH26":9.48,"WL26":4.17,"WH52":9.48,"WL52":4.17,"vrate":424,"trate":2,"LRTH":7.41,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":5908,"OPOI":1326,"PCOIR":0.22,"pos":-500,"avgP":7.56}},{"_mkdata":{"sym":"CCIH","bid":13.24,"ask":13.39,"bs":15,"as":1,"H":13.32,"L":13.15,"C":13.35,"O":13.22,"LP":13.27,"WH13":15.69,"WL13":8.26,"WH26":15.69,"WL26":7.91,"WH52":17.17,"WL52":7.91,"vrate":2828,"trate":0,"LRTH":13.35,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":3147,"OPOI":423,"PCOIR":0.13,"pos":0,"avgP":0}},{"_mkdata":{"sym":"BIDU","bid":209.25,"ask":209.52,"bs":3,"as":3,"H":211,"L":209.19,"C":210.31,"O":211,"LP":209.37,"WH13":223.94,"WL13":188.59,"WH26":237.43,"WL26":188.59,"WH52":251.99,"WL52":176.69,"vrate":15000,"trate":138,"LRTH":210.38,"OCVol":402,"OPVol":291,"PCVOR":0.72,"OCOI":145175,"OPOI":110343,"PCOIR":0.76,"pos":0,"avgP":0}},{"_mkdata":{"sym":"GOMO","bid":4.67,"ask":4.82,"bs":1,"as":1,"H":4.76,"L":4.76,"C":4.76,"O":5.08,"LP":0,"WH13":5.23,"WL13":3.35,"WH26":5.59,"WL26":3.25,"WH52":14.4,"WL52":3.25,"vrate":0,"trate":0,"LRTH":4.74,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":563,"OPOI":1417,"PCOIR":2.51,"pos":0,"avgP":0}},{"_mkdata":{"sym":"JRJC","bid":5.80,"ask":5.84,"bs":4,"as":2,"H":5.87,"L":5.76,"C":5.90,"O":5.80,"LP":5.84,"WH13":6.40,"WL13":3.89,"WH26":6.75,"WL26":3.89,"WH52":11.88,"WL52":3.50,"vrate":1944,"trate":0,"LRTH":5.87,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":4751,"OPOI":2916,"PCOIR":0.61,"pos":0,"avgP":0}},{"_mkdata":{"sym":"ATHM","bid":50.10,"ask":50.39,"bs":1,"as":1,"H":51.45,"L":49.89,"C":51.53,"O":51.06,"LP":50.20,"WH13":56.57,"WL13":42.75,"WH26":56.57,"WL26":34.5,"WH52":57.88,"WL52":31.85,"vrate":8202,"trate":22,"LRTH":51.50,"OCVol":828,"OPVol":12,"PCVOR":0.01,"OCOI":5876,"OPOI":3176,"PCOIR":0.54,"pos":0,"avgP":0}},{"_mkdata":{"sym":"HMIN","bid":0,"ask":0,"bs":0,"as":0,"H":0,"L":0,"C":0,"O":0,"LP":31.31,"WH13":0,"WL13":0,"WH26":0,"WL26":0,"WH52":0,"WL52":0,"vrate":0,"trate":0,"LRTH":0,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":0,"OPOI":0,"PCOIR":-1,"pos":-100,"avgP":30.89}},{"_mkdata":{"sym":"TAOM","bid":0,"ask":0,"bs":0,"as":0,"H":0,"L":0,"C":0,"O":0,"LP":3.43,"WH13":0,"WL13":0,"WH26":0,"WL26":0,"WH52":0,"WL52":0,"vrate":0,"trate":0,"LRTH":0,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":0,"OPOI":0,"PCOIR":-1,"pos":300,"avgP":3.12}},{"_mkdata":{"sym":"WUBA","bid":67.70,"ask":68.09,"bs":1,"as":1,"H":69.10,"L":67.70,"C":69.12,"O":69.06,"LP":67.87,"WH13":83.70,"WL13":47.24,"WH26":83.70,"WL26":37.17,"WH52":83.70,"WL52":34.64,"vrate":10800,"trate":66,"LRTH":69.04,"OCVol":28,"OPVol":0,"PCVOR":-1,"OCOI":11095,"OPOI":18530,"PCOIR":1.67,"pos":0,"avgP":0}},{"_mkdata":{"sym":"WB","bid":18.64,"ask":18.69,"bs":6,"as":8,"H":19,"L":18.62,"C":19.03,"O":18.87,"LP":18.64,"WH13":20.69,"WL13":12.65,"WH26":20.69,"WL26":12.10,"WH52":26.07,"WL52":12.10,"vrate":3300,"trate":3,"LRTH":19.03,"OCVol":40,"OPVol":50,"PCVOR":1.25,"OCOI":22509,"OPOI":6106,"PCOIR":0.27,"pos":0,"avgP":0}},{"_mkdata":{"sym":"YY","bid":74,"ask":74.5,"bs":1,"as":5,"H":75.53,"L":71.59,"C":75.5,"O":75.53,"LP":74.23,"WH13":81.70,"WL13":52.84,"WH26":81.70,"WL26":50.52,"WH52":96.39,"WL52":50.52,"vrate":1150,"trate":0,"LRTH":75.51,"OCVol":95,"OPVol":57,"PCVOR":0.59,"OCOI":31251,"OPOI":44298,"PCOIR":1.41,"pos":50,"avgP":69.26}},{"_mkdata":{"sym":"ZNH","bid":-1,"ask":-1,"bs":0,"as":0,"H":0,"L":0,"C":63.28,"O":0,"LP":0,"WH13":64.42,"WL13":30.16,"WH26":64.42,"WL26":22.48,"WH52":64.42,"WL52":14.9,"vrate":0,"trate":0,"LRTH":63.35,"OCVol":0,"OPVol":0,"PCVOR":-1,"OCOI":1187,"OPOI":984,"PCOIR":0.8,"pos":0,"avgP":0}},{"_portfolio":{"uPNL":-0.05,"aPNL":101.19,"lcc":144000,"inve":38245.24,"cR":105754.74,"nlc":2658408.39}}]}'''
  t0 = ujson.loads(s0)
  t1 = ujson.loads(s1)
  n = diff(t0,t1)
  print n
